package com.ruoyi.order.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.order.domain.TCanteenOrderDetail;
import com.ruoyi.order.service.ITCanteenOrderDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单明细Controller
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/order/detail")
public class TCanteenOrderDetailController extends BaseController
{
    @Autowired
    private ITCanteenOrderDetailService tCanteenOrderDetailService;

    /**
     * 查询订单明细列表
     */
    @PreAuthorize("@ss.hasPermi('order:detail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCanteenOrderDetail tCanteenOrderDetail)
    {
        startPage();
        List<TCanteenOrderDetail> list = tCanteenOrderDetailService.selectTCanteenOrderDetailList(tCanteenOrderDetail);
        return getDataTable(list);
    }

    /**
     * 导出订单明细列表
     */
    @PreAuthorize("@ss.hasPermi('order:detail:export')")
    @Log(title = "订单明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCanteenOrderDetail tCanteenOrderDetail)
    {
        List<TCanteenOrderDetail> list = tCanteenOrderDetailService.selectTCanteenOrderDetailList(tCanteenOrderDetail);
        ExcelUtil<TCanteenOrderDetail> util = new ExcelUtil<TCanteenOrderDetail>(TCanteenOrderDetail.class);
        util.exportExcel(response, list, "订单明细数据");
    }

    /**
     * 获取订单明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:detail:query')")
    @GetMapping(value = "/{detailId}")
    public AjaxResult getInfo(@PathVariable("detailId") Long detailId)
    {
        return success(tCanteenOrderDetailService.selectTCanteenOrderDetailByDetailId(detailId));
    }

    /**
     * 新增订单明细
     */
    @PreAuthorize("@ss.hasPermi('order:detail:add')")
    @Log(title = "订单明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCanteenOrderDetail tCanteenOrderDetail)
    {
        return toAjax(tCanteenOrderDetailService.insertTCanteenOrderDetail(tCanteenOrderDetail));
    }

    /**
     * 修改订单明细
     */
    @PreAuthorize("@ss.hasPermi('order:detail:edit')")
    @Log(title = "订单明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCanteenOrderDetail tCanteenOrderDetail)
    {
        return toAjax(tCanteenOrderDetailService.updateTCanteenOrderDetail(tCanteenOrderDetail));
    }

    /**
     * 删除订单明细
     */
    @PreAuthorize("@ss.hasPermi('order:detail:remove')")
    @Log(title = "订单明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{detailIds}")
    public AjaxResult remove(@PathVariable Long[] detailIds)
    {
        return toAjax(tCanteenOrderDetailService.deleteTCanteenOrderDetailByDetailIds(detailIds));
    }
}
